==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/relateandunrelate/impl/RelateUsingSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.relateandunrelate.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateUsing;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateUsingSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class RelateUsingSetImpl extends InstanceSet<RelateUsingSet,RelateUsing> implements RelateUsingSet {

    // attributes
    @Override
    public void setAssociative_Var_ID( UniqueId ref_Associative_Var_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociative_Var_ID( ref_Associative_Var_ID );
    }
    @Override
    public void setAssociationPhraseColumn( int m_associationPhraseColumn ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationPhraseColumn( m_associationPhraseColumn );
    }
    @Override
    public void setAssociationPhraseLineNumber( int m_associationPhraseLineNumber ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationPhraseLineNumber( m_associationPhraseLineNumber );
    }
    @Override
    public void setAssociationNumberColumn( int m_associationNumberColumn ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationNumberColumn( m_associationNumberColumn );
    }
    @Override
    public void setAssociationNumberLineNumber( int m_associationNumberLineNumber ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationNumberLineNumber( m_associationNumberLineNumber );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setOne_Side_Var_ID( UniqueId ref_One_Side_Var_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setOne_Side_Var_ID( ref_One_Side_Var_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setRelationship_phrase( String m_relationship_phrase ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setRelationship_phrase( m_relationship_phrase );
    }
    @Override
    public void setOther_Side_Var_ID( UniqueId ref_Other_Side_Var_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setOther_Side_Var_ID( ref_Other_Side_Var_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( RelateUsing relateusing : this ) act_smtset.add( relateusing.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_VARSet R617_one_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( RelateUsing relateusing : this ) v_varset.add( relateusing.R617_one_V_VAR() );
        return v_varset;
    }
    @Override
    public V_VARSet R618_other_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( RelateUsing relateusing : this ) v_varset.add( relateusing.R618_other_V_VAR() );
        return v_varset;
    }
    @Override
    public V_VARSet R619_using_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( RelateUsing relateusing : this ) v_varset.add( relateusing.R619_using_V_VAR() );
        return v_varset;
    }
    @Override
    public AssociationSet R654_creates_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( RelateUsing relateusing : this ) associationset.add( relateusing.R654_creates_Association() );
        return associationset;
    }


    @Override
    public RelateUsing nullElement() {
        return RelateUsingImpl.EMPTY_RELATEUSING;
    }

    @Override
    public RelateUsingSet emptySet() {
      return new RelateUsingSetImpl();
    }

    @Override
    public RelateUsingSet value() {
        return this;
    }

    @Override
    public List<RelateUsing> elements() {
        return Arrays.asList(toArray(new RelateUsing[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/relateandunrelate/impl/RelateUsingSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.relateandunrelate.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateUsing;
import io.ciera.tool.sql.ooaofooa.relateandunrelate.RelateUsingSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class RelateUsingSetImpl extends InstanceSet<RelateUsingSet,RelateUsing> implements RelateUsingSet {

    public RelateUsingSetImpl() {
    }

    public RelateUsingSetImpl(Comparator<? super RelateUsing> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setAssociationNumberLineNumber( int m_associationNumberLineNumber ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationNumberLineNumber( m_associationNumberLineNumber );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setAssociationPhraseLineNumber( int m_associationPhraseLineNumber ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationPhraseLineNumber( m_associationPhraseLineNumber );
    }
    @Override
    public void setAssociative_Var_ID( UniqueId ref_Associative_Var_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociative_Var_ID( ref_Associative_Var_ID );
    }
    @Override
    public void setOne_Side_Var_ID( UniqueId ref_One_Side_Var_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setOne_Side_Var_ID( ref_One_Side_Var_ID );
    }
    @Override
    public void setOther_Side_Var_ID( UniqueId ref_Other_Side_Var_ID ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setOther_Side_Var_ID( ref_Other_Side_Var_ID );
    }
    @Override
    public void setAssociationNumberColumn( int m_associationNumberColumn ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationNumberColumn( m_associationNumberColumn );
    }
    @Override
    public void setRelationship_phrase( String m_relationship_phrase ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setRelationship_phrase( m_relationship_phrase );
    }
    @Override
    public void setAssociationPhraseColumn( int m_associationPhraseColumn ) throws XtumlException {
        for ( RelateUsing relateusing : this ) relateusing.setAssociationPhraseColumn( m_associationPhraseColumn );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( RelateUsing relateusing : this ) act_smtset.add( relateusing.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_VARSet R617_one_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( RelateUsing relateusing : this ) v_varset.add( relateusing.R617_one_V_VAR() );
        return v_varset;
    }
    @Override
    public V_VARSet R618_other_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( RelateUsing relateusing : this ) v_varset.add( relateusing.R618_other_V_VAR() );
        return v_varset;
    }
    @Override
    public V_VARSet R619_using_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( RelateUsing relateusing : this ) v_varset.add( relateusing.R619_using_V_VAR() );
        return v_varset;
    }
    @Override
    public AssociationSet R654_creates_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( RelateUsing relateusing : this ) associationset.add( relateusing.R654_creates_Association() );
        return associationset;
    }


    @Override
    public RelateUsing nullElement() {
        return RelateUsingImpl.EMPTY_RELATEUSING;
    }

    @Override
    public RelateUsingSet emptySet() {
      return new RelateUsingSetImpl();
    }

    @Override
    public RelateUsingSet emptySet(Comparator<? super RelateUsing> comp) {
      return new RelateUsingSetImpl(comp);
    }

    @Override
    public RelateUsingSet value() {
        return this;
    }

    @Override
    public List<RelateUsing> elements() {
        return Arrays.asList(toArray(new RelateUsing[0]));
    }

}
